@@ -6,6 +6,7 @@ from typing import (
     ClassVar,
     Dict,
     Iterator,
+    List,
     Protocol,
     Tuple,
     Union,
@@ -38,6 +39,8 @@ T_BuiltinScalar = TypeVar(
     covariant=True,
 )
 
+ListOrTuple = Union[List[_T_Item], Tuple[_T_Item, ...]]
+
 
 @runtime_checkable
 class DataclassInstance(Protocol):
